@@ -16,20 +16,21 @@
  */
 package org.apache.commons.beanutils.converters;
 
-import java.util.Collections;
-import java.util.List;
-import java.util.ArrayList;
-import java.util.Iterator;
-import java.util.Collection;
+import java.io.IOException;
 import java.io.StreamTokenizer;
 import java.io.StringReader;
-import java.io.IOException;
 import java.lang.reflect.Array;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.Iterator;
+import java.util.List;
+
 import org.apache.commons.beanutils.ConversionException;
 import org.apache.commons.beanutils.Converter;
 
 /**
- * Generic {@link Converter} implementaion that handles conversion
+ * Generic {@link Converter} implementation that handles conversion
  * to and from <b>array</b> objects.
  * <p>
  * Can be configured to either return a <i>default value</i> or throw a
@@ -48,25 +49,25 @@ import org.apache.commons.beanutils.Converter;
  *         of the delegate {@link Converter}.</li>
  *     <li><b>Delimited Lists</b> - can Convert <b>to</b> and <b>from</b> a
  *         delimited list in String format.</li>
- *     <li><b>Conversion to String</b> - converts an array to a 
+ *     <li><b>Conversion to String</b> - converts an array to a
  *         <code>String</code> in one of two ways: as a <i>delimited list</i>
  *         or by converting the first element in the array to a String - this
  *         is controlled by the {@link ArrayConverter#setOnlyFirstToString(boolean)}
  *         parameter.</li>
- *     <li><b>Multi Dimensional Arrays</b> - its possible to convert a <code>String</code>
+ *     <li><b>Multi Dimensional Arrays</b> - it is possible to convert a <code>String</code>
  *         to a multi-dimensional arrays, by embedding {@link ArrayConverter}
  *         within each other - see example below.</li>
  *     <li><b>Default Value</b></li>
  *         <ul>
- *             <li><b><i>No Default</b></i> - use the 
+ *             <li><b><i>No Default</b></i> - use the
  *                 {@link ArrayConverter#ArrayConverter(Class, Converter)}
  *                 constructor to create a converter which throws a
  *                 {@link ConversionException} if the value is missing or
  *                 invalid.</li>
- *             <li><b><i>Default values</b></i> - use the 
+ *             <li><b><i>Default values</b></i> - use the
  *                 {@link ArrayConverter#ArrayConverter(Class, Converter, int)}
  *                 constructor to create a converter which returns a <i>default
- *                 value</i>. The <i>defaultSize</i> parameter controls the 
+ *                 value</i>. The <i>defaultSize</i> parameter controls the
  *                 <i>default value</i> in the following way:</li>
  *                 <ul>
  *                    <li><i>defaultSize &lt; 0</i> - default is <code>null</code></li>
@@ -121,13 +122,13 @@ import org.apache.commons.beanutils.Converter;
  *    int[][] result = (int[][])matrixConverter.convert(int[][].class, matrixString);
  * </pre>
  *
- * @version $Revision: 640131 $ $Date: 2008-03-23 02:10:31 +0000 (Sun, 23 Mar 2008) $
+ * @version $Id: ArrayConverter.java 1540518 2013-11-10 19:04:04Z oheger $
  * @since 1.8.0
  */
 public class ArrayConverter extends AbstractConverter {
 
-    private Object defaultTypeInstance;
-    private Converter elementConverter;
+    private final Class<?> defaultType;
+    private final Converter elementConverter;
     private int defaultSize;
     private char delimiter    = ',';
     private char[] allowedChars = new char[] {'.', '-'};
@@ -145,7 +146,7 @@ public class ArrayConverter extends AbstractConverter {
      * @param elementConverter Converter used to convert
      *  individual array elements.
      */
-    public ArrayConverter(Class defaultType, Converter elementConverter) {
+    public ArrayConverter(Class<?> defaultType, Converter elementConverter) {
         super();
         if (defaultType == null) {
             throw new IllegalArgumentException("Default type is missing");
@@ -156,7 +157,7 @@ public class ArrayConverter extends AbstractConverter {
         if (elementConverter == null) {
             throw new IllegalArgumentException("Component Converter is missing.");
         }
-        this.defaultTypeInstance = Array.newInstance(defaultType.getComponentType(), 0);
+        this.defaultType = defaultType;
         this.elementConverter = elementConverter;
     }
 
@@ -172,7 +173,7 @@ public class ArrayConverter extends AbstractConverter {
      * @param defaultSize Specifies the size of the default array value or if less
      *  than zero indicates that a <code>null</code> default value should be used.
      */
-    public ArrayConverter(Class defaultType, Converter elementConverter, int defaultSize) {
+    public ArrayConverter(Class<?> defaultType, Converter elementConverter, int defaultSize) {
         this(defaultType, elementConverter);
         this.defaultSize = defaultSize;
         Object defaultValue = null;
@@ -208,7 +209,7 @@ public class ArrayConverter extends AbstractConverter {
      * @param onlyFirstToString <code>true</code> converts only
      * the first value in the array to a String, <code>false</code>
      * converts all values in the array into a delimited list (default
-     * is <code>true</code> 
+     * is <code>true</code>
      */
     public void setOnlyFirstToString(boolean onlyFirstToString) {
         this.onlyFirstToString = onlyFirstToString;
@@ -219,8 +220,9 @@ public class ArrayConverter extends AbstractConverter {
      *
      * @return The default type this <code>Converter</code> handles.
      */
-    protected Class getDefaultType() {
-        return defaultTypeInstance.getClass();
+    @Override
+    protected Class<?> getDefaultType() {
+        return defaultType;
     }
 
     /**
@@ -230,15 +232,16 @@ public class ArrayConverter extends AbstractConverter {
      * @return the converted String value.
      * @throws Throwable if an error occurs converting to a String
      */
+    @Override
     protected String convertToString(Object value) throws Throwable {
 
         int size = 0;
-        Iterator iterator = null;
-        Class type = value.getClass();
+        Iterator<?> iterator = null;
+        Class<?> type = value.getClass();
         if (type.isArray()) {
             size = Array.getLength(value);
         } else {
-            Collection collection = convertToCollection(type, value);
+            Collection<?> collection = convertToCollection(type, value);
             size = collection.size();
             iterator = collection.iterator();
         }
@@ -252,7 +255,7 @@ public class ArrayConverter extends AbstractConverter {
         }
 
         // Create a StringBuffer containing a delimited list of the values
-        StringBuffer buffer = new StringBuffer();
+        StringBuilder buffer = new StringBuilder();
         for (int i = 0; i < size; i++) {
             if (i > 0) {
                 buffer.append(delimiter);
@@ -271,12 +274,14 @@ public class ArrayConverter extends AbstractConverter {
     /**
      * Handles conversion to an array of the specified type.
      *
+     * @param <T> Target type of the conversion.
      * @param type The type to which this value should be converted.
      * @param value The input value to be converted.
      * @return The converted value.
      * @throws Throwable if an error occurs converting to the specified type
      */
-    protected Object convertToType(Class type, Object value) throws Throwable {
+    @Override
+    protected <T> T convertToType(Class<T> type, Object value) throws Throwable {
 
         if (!type.isArray()) {
             throw new ConversionException(toString(getClass())
@@ -286,17 +291,17 @@ public class ArrayConverter extends AbstractConverter {
 
         // Handle the source
         int size = 0;
-        Iterator iterator = null;
+        Iterator<?> iterator = null;
         if (value.getClass().isArray()) {
             size = Array.getLength(value);
         } else {
-            Collection collection = convertToCollection(type, value);
+            Collection<?> collection = convertToCollection(type, value);
             size = collection.size();
             iterator = collection.iterator();
         }
 
         // Allocate a new Array
-        Class componentType = type.getComponentType();
+        Class<?> componentType = type.getComponentType();
         Object newArray = Array.newInstance(componentType, size);
 
         // Convert and set each element in the new Array
@@ -308,7 +313,11 @@ public class ArrayConverter extends AbstractConverter {
             Array.set(newArray, i, element);
         }
 
-        return newArray;
+        @SuppressWarnings("unchecked")
+        // This is safe because T is an array type and newArray is an array of
+        // T's component type
+        T result = (T) newArray;
+        return result;
     }
 
     /**
@@ -317,6 +326,7 @@ public class ArrayConverter extends AbstractConverter {
      * @param value The value to convert
      * @return The value unchanged
      */
+    @Override
     protected Object convertArray(Object value) {
         return value;
     }
@@ -327,7 +337,7 @@ public class ArrayConverter extends AbstractConverter {
      * </p>
      * <ul>
      *   <li>{@link Collection} values are returned unchanged</li>
-     *   <li>{@link Number}, {@link Boolean}  and {@link java.util.Date} 
+     *   <li>{@link Number}, {@link Boolean}  and {@link java.util.Date}
      *       values returned as a the only element in a List.</li>
      *   <li>All other types are converted to a String and parsed
      *       as a delimited list.</li>
@@ -342,18 +352,18 @@ public class ArrayConverter extends AbstractConverter {
      * @param value value to be converted
      * @return Collection elements.
      */
-    protected Collection convertToCollection(Class type, Object value) {
+    protected Collection<?> convertToCollection(Class<?> type, Object value) {
         if (value instanceof Collection) {
-            return (Collection)value;
+            return (Collection<?>)value;
         }
         if (value instanceof Number ||
             value instanceof Boolean ||
             value instanceof java.util.Date) {
-            List list = new ArrayList(1);
+            List<Object> list = new ArrayList<Object>(1);
             list.add(value);
             return list;
         }
-        
+
         return parseElements(type, value.toString());
     }
 
@@ -363,7 +373,8 @@ public class ArrayConverter extends AbstractConverter {
      * @param type Data type to which this value should be converted.
      * @return The default value for the specified type.
      */
-    protected Object getDefault(Class type) {
+    @Override
+    protected Object getDefault(Class<?> type) {
         if (type.equals(String.class)) {
             return null;
         }
@@ -386,8 +397,9 @@ public class ArrayConverter extends AbstractConverter {
      *
      * @return A String representation of this array converter
      */
+    @Override
     public String toString() {
-        StringBuffer buffer = new StringBuffer();
+        StringBuilder buffer = new StringBuilder();
         buffer.append(toString(getClass()));
         buffer.append("[UseDefault=");
         buffer.append(isUseDefault());
@@ -419,7 +431,7 @@ public class ArrayConverter extends AbstractConverter {
      * @throws NullPointerException if <code>svalue</code>
      *  is <code>null</code>
      */
-    private List parseElements(Class type, String value) {
+    private List<String> parseElements(Class<?> type, String value) {
 
         if (log().isDebugEnabled()) {
             log().debug("Parsing elements, delimiter=[" + delimiter + "], value=[" + value + "]");
@@ -444,13 +456,13 @@ public class ArrayConverter extends AbstractConverter {
             }
 
             // Split comma-delimited tokens into a List
-            List list = null;
+            List<String> list = null;
             while (true) {
                 int ttype = st.nextToken();
                 if ((ttype == StreamTokenizer.TT_WORD) || (ttype > 0)) {
                     if (st.sval != null) {
                         if (list == null) {
-                            list = new ArrayList();
+                            list = new ArrayList<String>();
                         }
                         list.add(st.sval);
                     }
@@ -463,7 +475,7 @@ public class ArrayConverter extends AbstractConverter {
             }
 
             if (list == null) {
-                list = Collections.EMPTY_LIST;
+                list = Collections.emptyList();
             }
             if (log().isDebugEnabled()) {
                 log().debug(list.size() + " elements parsed");
