@@ -33,20 +33,19 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * Test case for Jira issue# BEANUTILS-61.
- * <p />
- * See https://issues.apache.org/jira/browse/BEANUTILS-61
- * <p />
  *
+ * <p>
  * {@link WrapDynaBean} is a secial case for the PropertyUtils's
  * isReadable() and isWriteable() methods - since the bean being
  * wrapped may have read-only or write-only properties (unlike
  * regular DynaBeans.
  *
- * @version $Revision: 553357 $ $Date: 2007-07-05 02:10:25 +0100 (Thu, 05 Jul 2007) $
+ * @version $Id: Jira61TestCase.java 1540186 2013-11-08 21:08:30Z oheger $
+ * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-61">https://issues.apache.org/jira/browse/BEANUTILS-61</a>
  */
 public class Jira61TestCase extends TestCase {
 
-    private Log log = LogFactory.getLog(Jira61TestCase.class);
+    private final Log log = LogFactory.getLog(Jira61TestCase.class);
     private Jira61BeanFactory.TestBean testBean;
     private WrapDynaBean wrapDynaBean;
 
@@ -82,6 +81,7 @@ public class Jira61TestCase extends TestCase {
      *
      * @throws java.lang.Exception
      */
+    @Override
     protected void setUp() throws Exception {
         super.setUp();
         testBean = Jira61BeanFactory.createBean();
@@ -95,6 +95,7 @@ public class Jira61TestCase extends TestCase {
      *
      * @throws java.lang.Exception
      */
+    @Override
     protected void tearDown() throws Exception {
         super.tearDown();
     }
@@ -402,7 +403,7 @@ public class Jira61TestCase extends TestCase {
      */
     public void testIssue_BEANUTILS_61_PropertyUtils_copyProperties_to_WrapDynaBean() {
         String value = "copied simpleReadOnly";
-        Map source = new HashMap();
+        Map<String, Object> source = new HashMap<String, Object>();
         source.put("simpleReadOnly", value);
         try {
             PropertyUtils.copyProperties(wrapDynaBean, source);
@@ -436,7 +437,7 @@ public class Jira61TestCase extends TestCase {
      */
     public void testIssue_BEANUTILS_61_BeanUtils_copyProperties_to_WrapDynaBean() {
         String value = "copied simpleReadOnly";
-        Map source = new HashMap();
+        Map<String, Object> source = new HashMap<String, Object>();
         source.put("simpleReadOnly", value);
         try {
             BeanUtils.copyProperties(wrapDynaBean, source);
