@@ -25,13 +25,14 @@ import java.util.GregorianCalendar;
 import java.util.Locale;
 
 import junit.framework.TestCase;
-import org.apache.commons.beanutils.Converter;
+
 import org.apache.commons.beanutils.ConversionException;
+import org.apache.commons.beanutils.Converter;
 
 /**
  * Abstract base for &lt;Date&gt;Converter classes.
  *
- * @version $Revision: 471689 $ $Date: 2006-11-06 10:52:49 +0000 (Mon, 06 Nov 2006) $
+ * @version $Id: DateConverterTestBase.java 1540186 2013-11-08 21:08:30Z oheger $
  */
 
 public abstract class DateConverterTestBase extends TestCase {
@@ -39,7 +40,7 @@ public abstract class DateConverterTestBase extends TestCase {
     // ------------------------------------------------------------------------
 
     /**
-     * Construtc a new test case.
+     * Construct a new test case.
      * @param name Name of the test
      */
     public DateConverterTestBase(String name) {
@@ -53,7 +54,7 @@ public abstract class DateConverterTestBase extends TestCase {
      * @return A new Converter
      */
     protected abstract DateTimeConverter makeConverter();
-    
+
     /**
      * Create the Converter with a default value.
      * @param defaultValue The default value
@@ -65,11 +66,11 @@ public abstract class DateConverterTestBase extends TestCase {
      * Return the expected type
      * @return The expected type
      */
-    protected abstract Class getExpectedType();
+    protected abstract Class<?> getExpectedType();
 
     /**
      * Convert from a Calendar to the appropriate Date type
-     * 
+     *
      * @param value The Calendar value to convert
      * @return The converted value
      */
@@ -111,7 +112,7 @@ public abstract class DateConverterTestBase extends TestCase {
             new java.sql.Time(now),
             new java.sql.Timestamp(now)
         };
-        
+
         // Initialize calendar also with same ms to avoid a failing test in a new time slice
         ((GregorianCalendar)date[1]).setTime(new Date(now));
 
@@ -139,7 +140,7 @@ public abstract class DateConverterTestBase extends TestCase {
         String testString = "2006-10-29";
         Calendar calendar = toCalendar(testString, pattern, null);
         Object expected   = toType(calendar);
-        
+
         Object result = converter.convert(null, testString);
         if (getExpectedType().equals(Calendar.class)) {
             assertTrue("TYPE ", getExpectedType().isAssignableFrom(result.getClass()));
@@ -152,7 +153,7 @@ public abstract class DateConverterTestBase extends TestCase {
     /**
      * Test default String to type conversion
      *
-     * N.B. This method is overriden by test case
+     * N.B. This method is overridden by test case
      * implementations for java.sql.Date/Time/Timestamp
      */
     public void testDefaultStringToTypeConvert() {
@@ -394,8 +395,8 @@ public abstract class DateConverterTestBase extends TestCase {
         String msg = "Converting '" + valueType + "' value '" + value + "'";
         try {
             Object result = converter.convert(getExpectedType(), value);
-            Class resultType = (result   == null ? null : result.getClass());
-            Class expectType = (expected == null ? null : expected.getClass());
+            Class<?> resultType = (result   == null ? null : result.getClass());
+            Class<?> expectType = (expected == null ? null : expected.getClass());
             assertEquals("TYPE "  + msg, expectType, resultType);
             assertEquals("VALUE " + msg, expected, result);
         } catch (Exception ex) {
@@ -414,8 +415,8 @@ public abstract class DateConverterTestBase extends TestCase {
         String msg = "Converting '" + valueType + "' value '" + value + "' to String";
         try {
             Object result = converter.convert(String.class, value);
-            Class resultType = (result   == null ? null : result.getClass());
-            Class expectType = (expected == null ? null : expected.getClass());
+            Class<?> resultType = (result   == null ? null : result.getClass());
+            Class<?> expectType = (expected == null ? null : expected.getClass());
             assertEquals("TYPE "  + msg, expectType, resultType);
             assertEquals("VALUE " + msg, expected, result);
         } catch (Exception ex) {
@@ -433,7 +434,7 @@ public abstract class DateConverterTestBase extends TestCase {
         String msg = "Converting '" + valueType + "' value '" + value + "'";
         try {
             Object result = converter.convert(getExpectedType(), value);
-            fail(msg + ", expected ConversionException, but result = '" + result + "'"); 
+            fail(msg + ", expected ConversionException, but result = '" + result + "'");
         } catch (ConversionException ex) {
             // Expected Result
         }
@@ -461,7 +462,7 @@ public abstract class DateConverterTestBase extends TestCase {
     Calendar toCalendar(String value, String pattern, Locale locale) {
         Calendar calendar = null;
         try {
-            DateFormat format = (locale == null) 
+            DateFormat format = (locale == null)
                            ? new SimpleDateFormat(pattern)
                            : new SimpleDateFormat(pattern, locale);
             format.setLenient(false);
